--- old/usr/src/uts/common/fs/tmpfs/tmp_vfsops.c	2016-07-18 05:54:33.932734883 +0100
+++ new/usr/src/uts/common/fs/tmpfs/tmp_vfsops.c	2016-07-18 05:54:33.949620997 +0100
@@ -21,6 +21,7 @@
 /*
  * Copyright (c) 1990, 2010, Oracle and/or its affiliates. All rights reserved.
  * Copyright (c) 2011, Joyent, Inc. All rights reserved.
+ * Copyright 2016 RackTop Systems.
  */
 
 #include <sys/types.h>
@@ -586,12 +587,14 @@
 	mutex_exit(&anoninfo_lock);
 
 	/*
-	 * If tm_anonmax for this mount is less than the available swap space
-	 * (minus the amount tmpfs can't use), use that instead
-	 */
-	if (blocks > tmpfs_minfree)
-		sbp->f_bfree = MIN(blocks - tmpfs_minfree,
-		    tm->tm_anonmax - tm->tm_anonmem);
+	 * If tm_anonmax is unbounded (set to ULONG_MAX) use available
+	 * swap space (minus the amount tmpfs can't use) otherwise use
+	 * tm_anonmax - tm_anonmem.
+	 */
+	if (tm->tm_anonmax == ULONG_MAX)
+		sbp->f_bfree = MAX(blocks - tmpfs_minfree, 0);
+	else if (blocks > tmpfs_minfree)
+		sbp->f_bfree = MAX(tm->tm_anonmax - tm->tm_anonmem, 0);
 	else
 		sbp->f_bfree = 0;
 
@@ -626,17 +629,13 @@
 
 	/*
 	 * The maximum number of files available is approximately the number
-	 * of tmpnodes we can allocate from the remaining kernel memory
-	 * available to tmpfs.  This is fairly inaccurate since it doesn't
-	 * take into account the names stored in the directory entries.
-	 */
-	if (tmpfs_maxkmem > tmp_kmemspace)
-		sbp->f_ffree = (tmpfs_maxkmem - tmp_kmemspace) /
-		    (sizeof (struct tmpnode) + sizeof (struct tdirent));
-	else
-		sbp->f_ffree = 0;
-
-	sbp->f_files = tmpfs_maxkmem /
+	 * of tmpnodes we can allocate from the number of blocks available
+	 * to this mount.  This is fairly inaccurate since it doesn't take
+	 * into account the names stored in the directory entries.
+	 */
+	sbp->f_ffree = sbp->f_bfree == 0 ? 0 : sbp->f_bfree /
+	    (sizeof (struct tmpnode) + sizeof (struct tdirent));
+	sbp->f_files = sbp->f_blocks == 0 ? 0 : sbp->f_blocks /
 	    (sizeof (struct tmpnode) + sizeof (struct tdirent));
 	sbp->f_favail = (fsfilcnt64_t)(sbp->f_ffree);
 	(void) cmpldev(&d32, vfsp->vfs_dev);
